@@ -22,9 +22,9 @@ def pytest_runtest_makereport(item, call):
     extra = getattr(report, "extra", [])
     screenshot = item.config.option.screenshot
 
-#report.when value --setup, call, teardown
+# report.when value --setup, call, teardown
     if report.when == 'call':
-        if not (screenshot == 'failonly' and report.outcome == 'passed'):
+        if item.funcargs['screenshot_count'] > 0:       # Handle non-breakable but script didn't handle fail case, therefore whole testcase will pass
             # item.module.test_obj.gif_file_name
             f_name = None
             if item.config.option.bdd_flag == 'Y':
@@ -41,7 +41,7 @@ def pytest_runtest_makereport(item, call):
 @pytest.fixture
 def test_obj(base_url, browser, browser_version, os_version, os_name, remote_flag, testrail_flag, tesults_flag,
              test_run_id, remote_project_name, remote_build_name, testname, reportportal_service, interactivemode_flag,
-             test_env, screenshot_option, xlsx_config, product, non_breakable, capture):
+             test_env, screenshot_option, xlsx_config, product, breakable, capture):
     "Return an instance of Base Page that knows about the third party integrations"
     try:
 
@@ -53,7 +53,7 @@ def test_obj(base_url, browser, browser_version, os_version, os_name, remote_fla
         #             browser, browser_version, os_version, os_name, remote_flag, testrail_flag, tesults_flag)
         test_obj = Zero_Page(base_url="http://", product=product)
         test_obj.test_env = test_env
-        test_obj.non_breakable = non_breakable
+        test_obj.breakable = breakable
         test_obj.screenshot = screenshot_option
         test_obj.set_calling_module(testname)
         test_obj.product = product
@@ -196,13 +196,13 @@ def testID(request):
 
 
 @pytest.fixture
-def non_breakable(request):
+def breakable(request):
     "pytest fixture for app activity"
     try:
-        if request.config.getoption("--non_breakable") == 'Y' or 'N':
-            return request.config.getoption("--non_breakable")
+        if request.config.getoption("--breakable") == 'Y' or 'N':
+            return request.config.getoption("--breakable")
         else:
-            raise Exception("Invalid value for -- non_breakable flag --- please enter Y or N")
+            raise Exception("Invalid value for -- breakable flag --- please enter Y or N")
 
     except Exception as e:
         print("Exception when trying to run test: %s" % __file__)
@@ -426,9 +426,9 @@ def pytest_addoption(parser):
                          dest="bdd_flag",
                          default='N',
                          help="Determine if the run is in BDD: Y or N")
-        parser.addoption("--non_breakable",
-                         dest="non_breakable",
-                         default='N',
+        parser.addoption("--breakable",
+                         dest="breakable",
+                         default='Y',
                          help="Determine when failure happen, the flow will break or not: Y or N")
         # parser.addoption("--bdd_flag",
         #                  dest="bdd_flag",
