@@ -27,7 +27,8 @@ class Wrapit():
         return inner
 
     def _screenshot(func):
-        "Decorator for taking screenshots"
+        """Decorator for taking screenshots
+        To use this function, it only expected used function will RETURN FALSE WHEN FAIL."""
 
         # Usage: Make this the first decorator to a method (right above the 'def function_name' line)
         # Otherwise, we cannot name the screenshot with the name of the function that called it
@@ -67,6 +68,10 @@ class Wrapit():
                 print("Exception when trying to run test: %s" % __file__)
                 print("Python says:%s" % str(e))
                 test_obj.write(traceback.format_exc())
+                if test_obj.screenshot != 'off':        # Add for handling fail screenshot *Break case (Take screenshot for non off case)
+                    screenshot_name = '%003d' % args[0].screenshot_counter + '_' + func.__name__
+                    args[0].screenshot_counter += 1
+                    args[0].save_screenshot(screenshot_name)
 
                 # Detail print in last line
                 with open(test_obj.logs_parent_dir + test_obj.log_name, "a") as logfile:
